.. _resources:

Locate resources
----------------

.. automethod:: cubicweb.web.webconfig.WebConfiguration.locate_resource
.. automethod:: cubicweb.web.webconfig.WebConfiguration.locate_doc_file
.. automethod:: cubicweb.web.webconfig.WebConfiguration.locate_all_files

Static files handling
---------------------

.. autoattribute:: cubicweb.web.webconfig.WebConfiguration.static_directory
.. automethod:: cubicweb.web.webconfig.WebConfiguration.static_file_exists
.. automethod:: cubicweb.web.webconfig.WebConfiguration.static_file_open
.. automethod:: cubicweb.web.webconfig.WebConfiguration.static_file_add
.. automethod:: cubicweb.web.webconfig.WebConfiguration.static_file_del

